import palettetools as pt

css = 'css'
json = 'json'
img1 = "https://assets.imgix.net/examples/bluehat.jpg"
img2 = "https://sherwinski.imgix.net/pineneedles.jpg"

print("Parsing for bluehat.jpg")
print("Running with css...\n")
print(pt.extract_colors_css(img1))
print("Running with json...\n")
print(pt.extract_colors_json(img1))
print("\nRunning for text color...\n")
print(pt.overlay_text_color(img1))

print("Parsing for pineneedles.jpg")
print("Running with css...\n")
print(pt.extract_colors_css(img2))
print("Running with json...\n")
print(pt.extract_colors_json(img2))
print("\nRunning for text color...\n")
print(pt.overlay_text_color(img2))


# -*- coding: utf-8 -*-

import requests as req
import ast
from constants import *

'''
	Extract the color palette of the image from the imgix-url passed in
	
'''
def extract_colors(url, responseType):
	resp = req.get(url + PALETTE_URL_PARAM + responseType)
	return ast.literal_eval(resp.text)
	
def extract_colors_css(url):
	resp = req.get(url + PALETTE_URL_PARAM + 'css')
	return resp.text

def extract_colors_json(url):
	resp = req.get(url + PALETTE_URL_PARAM + 'json')
	return ast.literal_eval(resp.text)

def overlay_text_color(url):
	resp = extract_colors(url, JSON_STRING)
	luminance = resp['average_luminance']

	if(luminance < .5):
		color = WHITE_HEX
	elif(luminance >= .5):
		color = BLACK_HEX

	return color